/*
 * Copyright (C) 2025 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { getUrl } from '@ngxp/rest';
import { HttpMethodE2E } from '../../../model/util';
import { HeaderE2EComponent } from '../../../page-objects/header.po';
import { MainPage } from '../../../page-objects/main.po';
import { getBaseUrl, intercept, waitOfInterceptor } from '../../../support/cypress-helper';
import { exist, shouldHaveAttribute } from '../../../support/cypress.util';
import { ApiRootLinkRelE2E } from '../../../support/linkrels';
import { loginAsAriane } from '../../../support/user-util';

describe('User Profile Menu', () => {
  const mainPage: MainPage = new MainPage();
  const header: HeaderE2EComponent = mainPage.getHeader();

  let documentationLink: string = '';

  before(() => {
    const interceptor: string = 'getApiRoot';
    intercept(HttpMethodE2E.GET, `${getBaseUrl()}/api`).as(interceptor);
    loginAsAriane();
    waitOfInterceptor(interceptor).then(
      (interception) => (documentationLink = getUrl(interception?.response?.body, ApiRootLinkRelE2E.DOCUMENTATIONS)),
    );
  });

  describe('open user profile menu', () => {
    before(() => {
      header.getCurrentUserProfile().getUserIconButton().click();
    });

    it('should show logout button', () => {
      exist(header.getCurrentUserProfile().getLogoutButton());
    });

    it('should show documentation', () => {
      exist(header.getCurrentUserProfile().getDocumentation());
    });

    it('should find documentation link', () => {
      shouldHaveAttribute(header.getCurrentUserProfile().getDocumentation().find('a'), 'href', documentationLink);
    });
  });
});
