/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { App } from 'apps/alfa-e2e/src/model/app';
import { getApp } from 'apps/alfa-e2e/src/support/app-util';
import { reload } from 'apps/alfa-e2e/src/support/cypress-helper';
import { UserE2E } from '../../../model/user';
import { HeaderE2EComponent } from '../../../page-objects/header.po';
import { LoginPage } from '../../../page-objects/login.po';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { exist } from '../../../support/cypress.util';
import { getUserSabine } from '../../../support/user-util';

describe('Login and Logout', () => {
  const app: App = getApp();
  const user: UserE2E = getUserSabine();

  const loginPage: LoginPage = new LoginPage();
  const mainPage: MainPage = new MainPage();
  const header: HeaderE2EComponent = mainPage.getHeader();

  before(() => {
    cy.logout();
  });

  it('should display accessibility link', () => {
    exist(loginPage.getBarrierefreiheitLink());
  });

  it('login as test user', () => {
    cy.visit('')
      .get('#kc-login')
      .should('exist')
      .get('#username')
      .type(user.name)
      .get('#password')
      .type(user.password)
      .get('#kc-login')
      .click();
  });

  it('should display Alfa logo', () => {
    waitForSpinnerToDisappear();

    exist(header.getLogo());
  });

  it('should keep user logged in on reload page', () => {
    reload();
    waitForSpinnerToDisappear();

    exist(header.getLogo());
  });

  it('should logout', () => {
    header.getCurrentUserProfile().logout();

    exist(loginPage.getLogin());
  });
});
