/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { registerLocaleData } from '@angular/common';
import localeDe from '@angular/common/locales/de';
import localeDeExtra from '@angular/common/locales/extra/de';
import {
  VorgangMoreMenuE2EComponent,
  VorgangMoreMenuVorpruefenItemE2EComponent,
} from 'apps/alfa-e2e/src/components/vorgang/vorgang-more-menu.e2e.components';
import {
  EingangE2E,
  EingangHeaderE2E,
  VorgangE2E,
  VorgangStatusE2E,
} from 'apps/alfa-e2e/src/model/vorgang';
import 'cypress-real-events/support';
import { KommentareInVorgangE2EComponent } from '../../../components/kommentar/kommentar-list.e2e.component';
import { VorgangListE2EComponent } from '../../../components/vorgang/vorgang-list.e2e.component';
import { MainPage, waitForSpinnerToDisappear } from '../../../page-objects/main.po';
import { VorgangPage } from '../../../page-objects/vorgang.po';
import { dropCollections } from '../../../support/cypress-helper';
import { exist, notExist } from '../../../support/cypress.util';
import { loginAsSabine } from '../../../support/user-util';
import {
  buildVorgang,
  createVorgang,
  initVorgaenge,
  objectIds,
} from '../../../support/vorgang-util';

registerLocaleData(localeDe, 'de', localeDeExtra);

describe.skip('Vorgang vorprüfen', () => {
  const mainPage: MainPage = new MainPage();
  const vorgangList: VorgangListE2EComponent = mainPage.getVorgangList();

  const vorgangPage: VorgangPage = new VorgangPage();
  const vorgangMoreMenu: VorgangMoreMenuE2EComponent = vorgangPage.getMoreMenu();
  const kommentarContainer: KommentareInVorgangE2EComponent = vorgangPage.getKommentarContainer();

  const vorgangOhnePruefung: VorgangE2E = {
    ...buildVorgang(objectIds[0], 'NichtZuPruefen'),
    status: VorgangStatusE2E.NEU,
  };

  const formIdP: string = 'Erstattung_ERFOLG';
  const formEngineName: string = 'AFM';
  const eingangHeader: EingangHeaderE2E = { ...createVorgang().eingangs[0].header };

  const eingangP: EingangE2E = {
    ...createVorgang().eingangs[0],
    header: { ...eingangHeader, formId: formIdP, formEngineName },
  };
  const vorgangVorpruefenPositive: VorgangE2E = {
    ...createVorgang(),
    name: 'ZuPruefenPositive',
    eingangs: [eingangP],
  };

  const formIdN: string = 'Erstattung_FAIL';
  const eingangN: EingangE2E = {
    ...createVorgang().eingangs[0],
    header: { ...eingangHeader, formId: formIdN, formEngineName },
  };
  const vorgangVorpruefenNegative: VorgangE2E = {
    ...buildVorgang(objectIds[1], 'ZuPruefenNegative'),
    eingangs: [eingangN],
  };

  before(() => {
    initVorgaenge([vorgangOhnePruefung, vorgangVorpruefenPositive, vorgangVorpruefenNegative]);

    loginAsSabine();

    waitForSpinnerToDisappear();
    exist(vorgangList.getRoot());
  });

  after(() => {
    dropCollections();
  });

  describe('do vorprüfen...', () => {
    describe('...vorpruefen with positive answer from Prozessor', () => {
      const menuItem: VorgangMoreMenuVorpruefenItemE2EComponent =
        vorgangMoreMenu.getVorpruefenItem();
      const kommentarText = 'Positive text, tbd';

      it('should open Vorgang-Detail-Page', () => {
        vorgangList.getListItem(vorgangVorpruefenPositive.name).getRoot().click();
        waitForSpinnerToDisappear();

        exist(vorgangPage.getVorgangDetailHeader().getRoot());
      });

      it('should open "more menu"', () => {
        waitForSpinnerToDisappear();
        vorgangMoreMenu.getButton().click();

        exist(vorgangMoreMenu.getRoot());
      });

      it('should show "Vorgang vorpüfen" button', () => {
        exist(menuItem.getButton());
      });

      it.skip('AKTUELL FEHLER: should have a positive comment after Prüfung', () => {
        menuItem.getButton().click();
        exist(kommentarContainer.getKommentar(kommentarText).getRoot());
      });

      it('should close menu after Prüfung', () => {
        vorgangMoreMenu.getButton().click();
        vorgangPage.getSubnavigation().getBackButton().click();
      });
    });

    describe('...vorpruefen with negative answer from Prozessor', () => {
      const menuItem: VorgangMoreMenuVorpruefenItemE2EComponent =
        vorgangMoreMenu.getVorpruefenItem();
      const kommentarText = 'Negative text, tbd';

      it('Open Vorgang-Detail-Page', () => {
        vorgangList.getListItem(vorgangVorpruefenNegative.name).getRoot().click();
        waitForSpinnerToDisappear();

        exist(vorgangPage.getVorgangDetailHeader().getRoot());
      });

      it.skip('AKTUELL FEHLER: should have a negative comment after Prüfung', () => {
        vorgangMoreMenu.getButton().click();
        menuItem.getButton().click();
        exist(kommentarContainer.getKommentar(kommentarText).getRoot());
      });

      it('should close menu after Prüfung', () => {
        notExist(menuItem.getRoot());

        vorgangPage.getSubnavigation().getBackButton().click();
      });
    });

    describe('menu not available on other Vorgänge', () => {
      it('should not show more menu on other Vorgänge', () => {
        vorgangList.getListItem(vorgangOhnePruefung.name).getRoot().click();
        waitForSpinnerToDisappear();

        notExist(vorgangMoreMenu.getRoot());
      });
    });
  });
});
