import { VorgangFormularButtonsE2EComponent } from '../../components/vorgang/vorgang-formular-buttons.e2e.components';
import { VorgangPage } from '../../page-objects/vorgang.po';
import { contains, exist, notExist } from '../../support/cypress.util';

export class E2EVorgangVerifier {
  private readonly vorgangPage: VorgangPage = new VorgangPage();
  private readonly formularButtons: VorgangFormularButtonsE2EComponent = new VorgangFormularButtonsE2EComponent();

  public verifyVorgangDetailOpen(vorgangName: string): void {
    exist(this.vorgangPage.getVorgangDetailHeader().getRoot());
    contains(this.vorgangPage.getVorgangDetailHeader().getName(), vorgangName);
  }

  public verifyForwardingButtonExists(): void {
    exist(this.vorgangPage.getFormularButtons().getForwardButton());
  }

  public verifyNoForwardingButtonExists(): void {
    notExist(this.vorgangPage.getFormularButtons().getForwardButton());
  }

  public verifyVorgangIsLocked(): void {
    this.verifyFormularButtonsNotVisible();
    notExist(this.vorgangPage.getWiedervorlagenContainer().getCreateWiedervorlageButton());
    notExist(this.vorgangPage.getKommentarContainer().getHinzufuegenButton());
    notExist(this.vorgangPage.getPostfachMailcontainer().getCreateButtonWithText());
    notExist(this.vorgangPage.getPostfachMailcontainer().getCreateButtonWithoutText());
  }

  private verifyFormularButtonsNotVisible(): void {
    notExist(this.formularButtons.getAbschliessenButton());
    notExist(this.formularButtons.getBearbeitenButton());
    notExist(this.formularButtons.getBescheidenButton());
    notExist(this.formularButtons.getEndgueltigLoeschenButton());
    notExist(this.formularButtons.getForwardButton());
    notExist(this.formularButtons.getLoeschAnforderungZuruecknehmenButton());
    notExist(this.formularButtons.getVerwerfenButton());
    notExist(this.formularButtons.getWiedereroeffnenButton());
    notExist(this.formularButtons.getZurueckholenButton());
    notExist(this.formularButtons.getZurueckstellenButton());
  }
}
