/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CdkStepperModule } from '@angular/cdk/stepper';
import { CommonModule } from '@angular/common';
import { Component, HostBinding, effect, signal } from '@angular/core';
import { FormControl, FormGroup, ReactiveFormsModule } from '@angular/forms';
import { RouterModule } from '@angular/router';
import {
  AttachmentComponent,
  AttachmentIconComponent,
  AttachmentWrapperComponent,
  BescheidGenerateIconComponent,
  BescheidUploadIconComponent,
  ButtonCardComponent,
  ButtonComponent,
  CheckboxComponent,
  CloseIconComponent,
  ErrorMessageComponent,
  FieldsetComponent,
  FileUploadButtonComponent,
  IconComponent,
  InstantSearchComponent,
  RadioButtonCardComponent,
  SaveIconComponent,
  SendIconComponent,
  SpinnerIconComponent,
  StampIconComponent,
  TextInputComponent,
  TextareaComponent,
  TooltipDirective,
} from '@ods/system';

import { EMPTY_STRING } from '@alfa-client/tech-shared';
import { Resource } from '@ngxp/rest';
import {
  InstantSearchQuery,
  InstantSearchResult,
} from 'libs/design-system/src/lib/instant-search/instant-search/instant-search.model';
import { BescheidDialogExampleComponent } from './components/bescheid-dialog/bescheid-dialog.component';
import { CustomStepperComponent } from './components/cdk-demo/custom-stepper.component';

@Component({
  standalone: true,
  imports: [
    CheckboxComponent,
    FieldsetComponent,
    CommonModule,
    AttachmentComponent,
    AttachmentWrapperComponent,
    ButtonComponent,
    ButtonCardComponent,
    FileUploadButtonComponent,
    RouterModule,
    CdkStepperModule,
    CustomStepperComponent,
    BescheidDialogExampleComponent,
    RadioButtonCardComponent,
    ReactiveFormsModule,
    InstantSearchComponent,
    SaveIconComponent,
    SendIconComponent,
    StampIconComponent,
    CloseIconComponent,
    AttachmentIconComponent,
    BescheidGenerateIconComponent,
    BescheidUploadIconComponent,
    SpinnerIconComponent,
    TextareaComponent,
    TextInputComponent,
    TextareaComponent,
    ErrorMessageComponent,
    TooltipDirective,
    IconComponent,
  ],
  selector: 'app-root',
  templateUrl: './app.component.html',
})
export class AppComponent {
  darkMode = signal<boolean>(JSON.parse(window.localStorage.getItem('darkMode') ?? 'false'));

  @HostBinding('class.dark') get mode() {
    return this.darkMode();
  }

  title = 'demo';

  instantSearchItems: InstantSearchResult<Resource>[] = [
    {
      title: 'Landeshauptstadt Kiel - Ordnungsamt, Gewerbe- und Schornsteinfegeraufsicht',
      description: 'Fabrikstraße  8-10, 24103 Kiel',
    },
    {
      title: 'Amt für Digitalisierung, Breitband und Vermessung Nürnberg Außenstelle Hersbruck',
      description: 'Rathausmarkt 7, Hersbruck',
    },
    {
      title: 'Amt für Digitalisierung, Breitband und Vermessung Stuttgart',
      description: 'Rathausmarkt 7, Stuttgart',
    },
    {
      title: 'Amt für Digitalisierung, Breitband und Vermessung Ulm',
      description: 'Rathausmarkt 7, Ulm',
    },
  ];
  instantSearchFormControl = new FormControl(EMPTY_STRING);

  getInstantSearchResults() {
    if (this.instantSearchFormControl.value.length < 2) return [];
    return this.instantSearchItems.filter((item) =>
      item.title.toLowerCase().includes(this.instantSearchFormControl.value.toLowerCase()),
    );
  }

  selectSearchResult(result: InstantSearchResult<Resource>) {
    console.log(result);
  }

  exampleForm = new FormGroup({
    exampleName: new FormControl('bewilligt'),
  });

  saveForm = new FormGroup({
    saveForm: new FormControl(),
  });

  onDownloadClick = () => window.alert('download clicked');

  constructor() {
    effect(() => {
      window.localStorage.setItem('darkMode', JSON.stringify(this.darkMode()));
    });
  }

  public onSearchQueryChanged(searchQuery: InstantSearchQuery) {
    console.info('Search query: %o', searchQuery);
  }
}
