import {
  ErrorRepresentation,
  KEYCLOAK_VALIDATION_ERROR_STATUS_CODES,
  KeycloakErrorResponseData,
  KeycloakHttpErrorResponse,
} from '@admin/keycloak-shared';
import { isNotNil } from '@alfa-client/tech-shared';
import { isNil } from 'lodash-es';

export function extractErrorRepresentations(error: KeycloakHttpErrorResponse): ErrorRepresentation[] {
  if (!canHandleKeycloakError(error)) {
    throw new Error(`Cannot handle keycloak error: ${error}`);
  }
  const errorResponseData: KeycloakErrorResponseData = error.responseData;
  return error.responseData.errors ?? [errorResponseData];
}

export function canHandleKeycloakError(err: KeycloakHttpErrorResponse): boolean {
  if (!KEYCLOAK_VALIDATION_ERROR_STATUS_CODES.includes(err?.response?.status)) return false;
  if (isNil(err?.responseData)) return false;

  if (containsErrorMessage(err)) return true;
  return containsErrorArray(err) && isNotNil(err.responseData.errors[0]?.errorMessage);
}

function containsErrorMessage(err: any): boolean {
  return isNotNil(err?.responseData?.errorMessage);
}

function containsErrorArray(err: any): boolean {
  return isNotNil(err?.responseData?.errors) && err.responseData.errors.length > 0;
}

export function isSingleErrorMessage(err: KeycloakErrorResponseData): boolean {
  return isNotNil(err.errorMessage) && isNil(err.field) && isNil(err.params) && isNil(err.errors);
}

export function isFieldErrorMessage(err: KeycloakErrorResponseData): boolean {
  return isNotNil(err.errorMessage) && isNotNil(err.field) && isNotNil(err.params) && isNil(err.errors);
}
