import { Mock, mock } from '@alfa-client/test-utils';
import { TestBed } from '@angular/core/testing';
import { faker } from '@faker-js/faker';
import { TokenProvider } from '@keycloak/keycloak-admin-client/lib/client';
import { OAuthService } from 'angular-oauth2-oidc';
import { KeycloakTokenService } from './keycloak-token.service';

import KcAdminClient from '@keycloak/keycloak-admin-client';

describe('KeycloakTokenService', () => {
  let service: KeycloakTokenService;

  let kcAdminClient: Mock<KcAdminClient>;
  let oAuthService: Mock<OAuthService>;

  const accessToken: string = faker.string.alphanumeric(40);

  beforeEach(() => {
    kcAdminClient = { ...mock(KcAdminClient), registerTokenProvider: jest.fn() };
    oAuthService = { ...mock(OAuthService), getAccessToken: jest.fn().mockReturnValue(accessToken) };

    TestBed.configureTestingModule({
      providers: [
        KeycloakTokenService,
        { provide: KcAdminClient, useValue: kcAdminClient },
        { provide: OAuthService, useValue: oAuthService },
      ],
    });
    service = TestBed.inject(KeycloakTokenService);
  });

  it('should be created', () => {
    expect(service).toBeTruthy();
  });

  describe('register access token provider', () => {
    it('should keycloak admin client to register token provider', () => {
      service.registerAccessTokenProvider();

      expect(kcAdminClient.registerTokenProvider).toHaveBeenCalledWith(
        expect.objectContaining({
          getAccessToken: expect.any(Function),
        }),
      );
    });
    it('should provide access token via token provider', async () => {
      const tokenProvider: TokenProvider = service['getTokenProvider']();
      const token = await tokenProvider.getAccessToken();

      expect(oAuthService.getAccessToken).toHaveBeenCalled();
      expect(token).toBe(accessToken);
    });

    it('should call registerTokenProvider with a valid token provider', () => {
      service.registerAccessTokenProvider();
    });
  });
});
