import { createEmptyStateResource, StateResource } from '@alfa-client/tech-shared';
import {
  dispatchEventFromFixture,
  existsAsHtmlElement,
  getElementComponentFromFixtureByCss,
  MockEvent,
} from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ButtonWithSpinnerComponent } from '@ods/component';
import { ButtonComponent } from '@ods/system';
import { MockComponent } from 'ng-mocks';
import { getDataTestIdOf } from '../../../../../../../../tech-shared/test/data-test';
import { OrganisationsEinheitDeleteDialogComponent } from './organisations-einheit-delete-dialog.component';

describe('OrganisationsEinheitDeleteDialogComponent', () => {
  let component: OrganisationsEinheitDeleteDialogComponent;
  let fixture: ComponentFixture<OrganisationsEinheitDeleteDialogComponent>;

  const deleteButton: string = getDataTestIdOf('dialog-delete-ods-button');
  const cancelButton: string = getDataTestIdOf('dialog-cancel-ods-button');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [
        OrganisationsEinheitDeleteDialogComponent,
        MockComponent(ButtonWithSpinnerComponent),
        MockComponent(ButtonComponent),
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(OrganisationsEinheitDeleteDialogComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('template', () => {
    describe('cancel button', () => {
      it('should exist', () => {
        existsAsHtmlElement(fixture, cancelButton);
      });

      it('should emit cancel on click', () => {
        component.cancel.emit = jest.fn();

        dispatchEventFromFixture(fixture, cancelButton, MockEvent.CLICK);

        expect(component.cancel.emit).toHaveBeenCalled();
      });
    });

    describe('delete button', () => {
      it('should exist', () => {
        existsAsHtmlElement(fixture, deleteButton);
      });

      it('should have inputs', () => {
        const stateResource: StateResource<void> = createEmptyStateResource();
        component.deleteStateResource = stateResource;

        fixture.detectChanges();

        const button: ButtonWithSpinnerComponent = getElementComponentFromFixtureByCss(fixture, deleteButton);
        expect(button.stateResource).toBe(stateResource);
      });

      it('should emit delete on click', () => {
        component.delete.emit = jest.fn();

        dispatchEventFromFixture(fixture, deleteButton, MockEvent.CLICK);

        expect(component.delete.emit).toHaveBeenCalled();
      });
    });
  });
});
