import { ROUTES } from '@admin-client/shared';
import { UserService } from '@admin-client/user-shared';
import { NavigationService } from '@alfa-client/navigation-shared';
import { createEmptyStateResource, isNotLoading, StateResource } from '@alfa-client/tech-shared';
import { AsyncPipe } from '@angular/common';
import { Component, inject } from '@angular/core';
import { Observable, of, tap } from 'rxjs';
import { UserFormService } from '../user.formservice';
import { UserDeleteDialogComponent } from './user-delete-dialog/user-delete-dialog.component';

@Component({
  selector: 'admin-delete-dialog-container',
  standalone: true,
  imports: [UserDeleteDialogComponent, AsyncPipe],
  templateUrl: './user-delete-dialog-container.component.html',
})
export class UserDeleteDialogContainerComponent {
  public readonly formService = inject(UserFormService);
  public readonly userService = inject(UserService);
  public readonly navigationService = inject(NavigationService);

  public deleteUserStateResource$: Observable<StateResource<unknown>> = of(createEmptyStateResource());

  public deleteUser(): void {
    this.deleteUserStateResource$ = this.userService
      .delete(this.formService.getId())
      .pipe(tap((state: StateResource<unknown>) => this.navigateOnDeleteSuccess(state)));
  }

  private navigateOnDeleteSuccess(state: StateResource<any>): void {
    if (isNotLoading(state)) {
      this.navigationService.navigate(ROUTES.BENUTZER);
    }
  }
}
