import { User, UserService } from '@admin-client/user-shared';
import { createEmptyStateResource, StateResource } from '@alfa-client/tech-shared';
import { getMockComponent, mock, Mock } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MockComponent } from 'ng-mocks';
import { Observable, of } from 'rxjs';
import { UserListContainerComponent } from './user-list-container.component';
import { UserListComponent } from './user-list/user-list.component';

describe('UserListContainerComponent', () => {
  let component: UserListContainerComponent;
  let fixture: ComponentFixture<UserListContainerComponent>;

  let userService: Mock<UserService>;

  const usersStateResource: StateResource<User[]> = createEmptyStateResource<User[]>();
  const usersStateResource$: Observable<StateResource<User[]>> = of(usersStateResource);

  beforeEach(async () => {
    userService = {
      ...mock(UserService),
      getAll: jest.fn().mockReturnValue(usersStateResource$),
      refresh: jest.fn(),
    };

    await TestBed.configureTestingModule({
      imports: [UserListContainerComponent, MockComponent(UserListComponent)],
      providers: [{ provide: UserService, useValue: userService }],
    }).compileComponents();

    fixture = TestBed.createComponent(UserListContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('component', () => {
    describe('ngOnInit', () => {
      it('should get users from userService', () => {
        component.ngOnInit();

        expect(component.usersStateResource$).toBe(usersStateResource$);
      });
    });
  });

  describe('template', () => {
    it('should have user list', async () => {
      const userList: UserListComponent = getMockComponent(fixture, UserListComponent);

      fixture.detectChanges();

      expect(userList.usersStateResource).toBe(usersStateResource);
    });
  });

  describe('on destroy', () => {
    it('should call service to refresh list', () => {
      component.ngOnDestroy();

      expect(userService.refresh).toHaveBeenCalled();
    });
  });
});
