/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import {
  CommandResource,
  CommandService,
  CreateCommand,
  CreateCommandProps,
} from '@alfa-client/command-shared';
import { EMPTY_STRING, StateResource } from '@alfa-client/tech-shared';
import { VorgangWithEingangLinkRel, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { Injectable } from '@angular/core';
import { Store } from '@ngrx/store';
import { Observable } from 'rxjs';

import * as BescheidSelectors from './bescheid.selectors';

@Injectable({ providedIn: 'root' })
export class BescheidFacade {
  constructor(
    private store: Store,
    private commandService: CommandService,
  ) {}

  public getBescheidCommand(): Observable<StateResource<CommandResource>> {
    return this.store.select(BescheidSelectors.bescheidCommand);
  }

  public createBescheidDraft(
    vorgangWithEingang: VorgangWithEingangResource,
    command: CreateCommand,
  ): void {
    const createCommandProps: CreateCommandProps = {
      resource: vorgangWithEingang,
      linkRel: VorgangWithEingangLinkRel.CREATE_BESCHEID_DRAFT,
      command,
      snackBarMessage: EMPTY_STRING,
    };
    this.commandService.createCommandByProps(createCommandProps);
  }
}
