/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidResource, BescheidWizardStep } from '@alfa-client/bescheid-shared';
import { isLoaded, StateResource } from '@alfa-client/tech-shared';
import { VorgangWithEingangLinkRel, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { Component, EventEmitter, Input, Output } from '@angular/core';
import { BescheidFormService } from '../bescheid.formservice';

@Component({
  selector: 'alfa-bescheid-wizard',
  templateUrl: './bescheid-wizard.component.html',
})
export class BescheidWizardComponent {
  @Input() vorgangWithEingangResource: VorgangWithEingangResource;

  @Input() set bescheidStateResource(value: StateResource<BescheidResource>) {
    if (isLoaded(value)) {
      this.formService.patchValues(value.resource);
      this.bescheidResource = value.resource;
    }
    this._bescheidStateResource = value;
  }

  get bescheidStateResource(): StateResource<BescheidResource> {
    return this._bescheidStateResource;
  }

  @Input() activeStep: BescheidWizardStep;

  @Output() vorgangAbgeschlossen: EventEmitter<void> = new EventEmitter<void>();

  public bescheidResource: BescheidResource;
  private _bescheidStateResource: StateResource<BescheidResource>;

  public readonly vorgangWithEingangLinkRel = VorgangWithEingangLinkRel;
  public readonly bescheidWizardStep = BescheidWizardStep;

  constructor(public readonly formService: BescheidFormService) {}
}
