/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidResource, BescheidService } from '@alfa-client/bescheid-shared';
import { tapOnCommandSuccessfullyDone } from '@alfa-client/command-shared';
import { isNotNil, StateResource } from '@alfa-client/tech-shared';
import { DIALOG_DATA, DialogRef } from '@angular/cdk/dialog';
import { Component, inject, OnDestroy, OnInit } from '@angular/core';
import { Resource } from '@ngxp/rest';
import { Observable } from 'rxjs';
import { BescheidFormService } from '../../bescheid.formservice';

export interface CancelWizardDialogData {
  bescheidResource: BescheidResource;
}

export interface CancelWizardDialogResult {
  closeWizard: boolean;
}

@Component({
  templateUrl: './bescheid-wizard-cancel-dialog-container.component.html',
})
export class BescheidWizardCancelDialogContainerComponent implements OnInit, OnDestroy {
  private readonly dialogData: CancelWizardDialogData = inject(DIALOG_DATA);
  private readonly dialogRef = inject(DialogRef);
  private readonly bescheidService = inject(BescheidService);
  private readonly formService = inject(BescheidFormService);

  public saveStateResource$: Observable<StateResource<Resource>>;
  public deleteStateResource$: Observable<StateResource<Resource>>;

  private readonly bescheidResource: BescheidResource = this.dialogData.bescheidResource;

  ngOnInit(): void {
    this.bescheidService.lockBescheidSending();
  }

  ngOnDestroy(): void {
    this.bescheidService.unlockBescheidSending();
  }

  public save(): void {
    this.saveStateResource$ = this.formService.submit().pipe(tapOnCommandSuccessfullyDone(() => this.closeDialogWithWizard()));
  }

  public cancel(): void {
    if (isNotNil(this.bescheidResource)) {
      this.deleteStateResource$ = this.bescheidService
        .deleteBescheid()
        .pipe(tapOnCommandSuccessfullyDone(() => this.closeDialogWithWizard()));
    } else {
      this.closeDialogWithWizard();
    }
  }

  closeDialogWithWizard(): void {
    this.dialogRef.close({ closeWizard: true });
  }
}
