/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { BescheidService } from '@alfa-client/bescheid-shared';
import { existsAsHtmlElement, Mock, mock, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { BeschiedenDateContainerComponent } from './beschieden-date-container/beschieden-date-container.component';
import { BeschiedenDateInVorgangContainerComponent } from './beschieden-date-in-vorgang-container.component';

describe('BeschiedenDateInVorgangContainerComponent', () => {
  let component: BeschiedenDateInVorgangContainerComponent;
  let fixture: ComponentFixture<BeschiedenDateInVorgangContainerComponent>;

  const beschiedenDate: string = getDataTestIdOf('beschieden-date');

  const bescheidService: Mock<BescheidService> = mock(BescheidService);

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [BeschiedenDateInVorgangContainerComponent, MockComponent(BeschiedenDateContainerComponent)],
      providers: [
        {
          provide: BescheidService,
          useValue: bescheidService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(BeschiedenDateInVorgangContainerComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should call service', () => {
      component.ngOnInit();

      expect(bescheidService.existBescheid).toHaveBeenCalled();
    });
  });

  describe('bescheide date', () => {
    it('should be visible if bescheid exists', () => {
      component.existBescheid$ = of(true);

      fixture.detectChanges();

      existsAsHtmlElement(fixture, beschiedenDate);
    });

    it('should be hidden if no bescheid exists', () => {
      component.existBescheid$ = of(false);

      fixture.detectChanges();

      notExistsAsHtmlElement(fixture, beschiedenDate);
    });
  });
});
