/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { argsToTemplate, moduleMetadata, type Meta, type StoryObj } from '@storybook/angular';

import { SaveIconComponent } from '../icons/save-icon/save-icon.component';
import { ButtonComponent } from './button.component';

const meta: Meta<ButtonComponent> = {
  title: 'Button',
  component: ButtonComponent,
  decorators: [
    moduleMetadata({
      imports: [ButtonComponent, SaveIconComponent],
    }),
  ],
  excludeStories: /.*Data$/,
  tags: ['autodocs'],
};

export default meta;
type Story = StoryObj<ButtonComponent>;

export const Default: Story = {
  args: {
    text: 'Hello world!',
    isLoading: false,
    disabled: false,
    destructive: false,
    variant: 'primary',
    size: 'medium',
    spinnerSize: 'medium',
  },
  argTypes: {
    variant: {
      options: ['primary', 'outline', 'ghost'],
      control: { type: 'radio' },
      table: { defaultValue: { summary: 'primary' } },
    },
    size: {
      options: ['medium', 'fit'],
      control: { type: 'select' },
      table: { defaultValue: { summary: 'medium' } },
    },
    spinnerSize: {
      description: 'Size of loading spinner',
      options: ['small', 'medium', 'large', 'extra-large', 'xxl', 'full'],
      control: { type: 'select' },
      table: { defaultValue: { summary: 'medium' } },
    },
    isLoading: { description: 'Show spinner icon if true' },
    destructive: { description: 'Red version of a button' },
  },
};

export const PrimaryWithIcon: Story = {
  args: {
    text: 'I have an icon',
    variant: 'primary',
  },
  render: (args) => ({
    props: args,
    template: `<ods-button ${argsToTemplate(args)}>
      <ods-save-icon icon size="small" class="fill-whitetext" />
    </ods-button>`,
  }),
};

export const SecondaryWithIcon: Story = {
  args: {
    text: 'I have an icon too',
    variant: 'outline',
  },
  render: (args) => ({
    props: args,
    template: `<ods-button ${argsToTemplate(args)}>
      <ods-save-icon icon size="small" />
    </ods-button>`,
  }),
};

export const SecondaryIconOnly: Story = {
  args: {
    variant: 'outline',
    size: 'fit',
  },
  render: (args) => ({
    props: args,
    template: `<ods-button ${argsToTemplate(args)}>
      <ods-save-icon icon size="small" />
    </ods-button>`,
  }),
};

export const IsLoading: Story = {
  args: {
    text: 'Loading...',
    isLoading: true,
  },
};

export const Disabled: Story = {
  args: {
    text: "Can't click me",
    disabled: true,
  },
};

export const GhostIcon: Story = {
  args: {
    variant: 'ghost',
    size: 'fit',
  },
  render: (args) => ({
    props: args,
    template: `<ods-button ${argsToTemplate(args)}>
      <ods-save-icon icon size='medium' />
    </ods-button>`,
  }),
};

export const GhostIconDestructive: Story = {
  args: {
    variant: 'ghost',
    size: 'fit',
    destructive: true,
  },
  render: (args) => ({
    props: args,
    template: `<ods-button ${argsToTemplate(args)}>
      <ods-save-icon icon size='medium' class="fill-destructive" />
    </ods-button>`,
  }),
};

export const GhostLoadingIcon: Story = {
  args: {
    variant: 'ghost',
    size: 'fit',
    isLoading: true,
  },
  render: (args) => ({
    props: args,
    template: `<ods-button ${argsToTemplate(args)}>
      <ods-save-icon icon size='medium' />
    </ods-button>`,
  }),
};

export const GhostButton: Story = {
  args: {
    variant: 'ghost',
    text: 'I am ghosted',
  },
};
