/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { getElementFromFixture } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { faker } from '@faker-js/faker';
import { expect } from '@jest/globals';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { FileUploadButtonComponent } from './file-upload-button.component';

describe('FileUploadButtonComponent', () => {
  let component: FileUploadButtonComponent;
  let fixture: ComponentFixture<FileUploadButtonComponent>;

  const labelText: string = faker.word.noun();
  const dataTestId: string = 'dummyDataTestId';
  const input: string = getDataTestIdOf(dataTestId);

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [FileUploadButtonComponent],
    }).compileComponents();

    fixture = TestBed.createComponent(FileUploadButtonComponent);
    component = fixture.componentInstance;
    component.id = labelText;
    component.dataTestId = dataTestId;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('click at file input', () => {
    it('should call resetInput()', () => {
      component.resetInput = jest.fn();
      const fileInput = getElementFromFixture(fixture, input);

      fileInput.click();
      fixture.detectChanges();

      expect(component.resetInput).toHaveBeenCalled();
    });
  });

  describe('template', () => {
    it('should have inputs', () => {
      component.multi = true;
      fixture.detectChanges();

      const inputElement: HTMLInputElement = getElementFromFixture(fixture, input);

      expect(inputElement.multiple).toEqual(component.multi);
    });
  });
});
