/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { CommandResource } from '@alfa-client/command-shared';
import { ForwardingLinkRel, ForwardingResource, ForwardingService } from '@alfa-client/forwarding-shared';
import { createEmptyStateResource, StateResource } from '@alfa-client/tech-shared';
import { Component, Input } from '@angular/core';
import { Observable, of } from 'rxjs';

@Component({
  selector: 'alfa-forward-by-email-zustellen-container',
  templateUrl: './forwarding-by-email-zustellen-container.component.html',
  styleUrls: ['./forwarding-by-email-zustellen-container.component.scss'],
})
export class ForwardingByEmailZustellenContainerComponent {
  @Input() forwarding: ForwardingResource;

  public markAsSuccessCommandStateResource$: Observable<StateResource<CommandResource>> =
    of(createEmptyStateResource<CommandResource>());
  public markAsFailCommandStateResource$: Observable<StateResource<CommandResource>> =
    of(createEmptyStateResource<CommandResource>());

  readonly linkRel = ForwardingLinkRel;

  constructor(private forwardingService: ForwardingService) {}

  markAsSuccess(): void {
    this.markAsSuccessCommandStateResource$ = this.forwardingService.markAsSuccess(this.forwarding);
  }

  markAsFail(): void {
    this.markAsFailCommandStateResource$ = this.forwardingService.markAsFail(this.forwarding);
  }
}
