/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ConvertToBooleanPipe } from '@alfa-client/tech-shared';
import { existsAsHtmlElement, notExistsAsHtmlElement } from '@alfa-client/test-utils';
import { registerLocaleData } from '@angular/common';
import localeDe from '@angular/common/locales/de';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { FormatFullDatePipe } from 'libs/tech-shared/src/lib/pipe/format-full-date.pipe';
import { getDataTestClassOf } from 'libs/tech-shared/test/data-test';
import { createBescheid } from '../../../../../../../bescheid-shared/src/test/bescheid';
import { HistorieItemBescheidStatusComponent } from './historie-item-bescheid-status.component';

registerLocaleData(localeDe);

describe('HistorieItemBescheidStatusComponent', () => {
  let component: HistorieItemBescheidStatusComponent;
  let fixture: ComponentFixture<HistorieItemBescheidStatusComponent>;

  const bewilligt: string = getDataTestClassOf('bewilligt');
  const abgelehnt: string = getDataTestClassOf('abgelehnt');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      imports: [ConvertToBooleanPipe, FormatFullDatePipe],
      declarations: [HistorieItemBescheidStatusComponent],
    }).compileComponents();

    fixture = TestBed.createComponent(HistorieItemBescheidStatusComponent);
    component = fixture.componentInstance;
    component.bescheid = { ...createBescheid(), bewilligt: 'false' };
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('on bewilligt', () => {
    beforeEach(() => {
      component.bescheid = { ...createBescheid(), bewilligt: 'true' };
      fixture.detectChanges();
    });

    it('should show bewilligt text', () => {
      existsAsHtmlElement(fixture, bewilligt);
    });

    it('should hide abgelehnt text', () => {
      notExistsAsHtmlElement(fixture, abgelehnt);
    });
  });

  describe('on abgelehnt', () => {
    beforeEach(() => {
      component.bescheid = { ...createBescheid(), bewilligt: 'false' };
      fixture.detectChanges();
    });
    it('should show abgelehnt text', () => {
      existsAsHtmlElement(fixture, abgelehnt);
    });

    it('should hide bewilligt text', () => {
      notExistsAsHtmlElement(fixture, bewilligt);
    });
  });
});
