/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Injectable } from '@angular/core';
import { CommandResource, CreateCommand } from '@alfa-client/command-shared';
import { StateResource } from '@alfa-client/tech-shared';
import { VorgangWithEingangLinkRel, VorgangWithEingangResource } from '@alfa-client/vorgang-shared';
import { Store } from '@ngrx/store';
import { Observable } from 'rxjs';
import { LoeschAnforderungLinkRel } from '../loesch-anforderung.linkrel';
import { LoeschAnforderungResource } from '../loesch-anforderung.model';

import * as CommandActions from '../../../../command-shared/src/lib/+state/command.actions';
import * as LoeschAnforderungActions from './loesch-anforderung.actions';
import * as LoeschAnforderungSelectors from './loesch-anforderung.selectors';

@Injectable()
export class LoeschAnforderungFacade {
  constructor(private readonly store: Store) {}

  public getLoeschenAnfordernCommand(): Observable<StateResource<CommandResource>> {
    return this.store.select(LoeschAnforderungSelectors.loeschenAnfordernCommand);
  }

  public getLoeschAnforderung(): Observable<StateResource<LoeschAnforderungResource>> {
    return this.store.select(LoeschAnforderungSelectors.loeschAnforderung);
  }

  public loadLoeschAnforderung(vorgangWithEingang: VorgangWithEingangResource): void {
    this.store.dispatch(LoeschAnforderungActions.loadLoeschAnforderung({ vorgangWithEingang }));
  }

  public loeschenAnfordern(
    vorgangWithEingang: VorgangWithEingangResource,
    command: CreateCommand,
  ): void {
    this.store.dispatch(
      CommandActions.createCommand({
        resource: vorgangWithEingang,
        linkRel: VorgangWithEingangLinkRel.LOESCHEN_ANFORDERN,
        command,
      }),
    );
  }

  public getEndgueltigLoeschenCommand(): Observable<StateResource<CommandResource>> {
    return this.store.select(LoeschAnforderungSelectors.vorgangLoeschenCommand);
  }

  public endgueltigLoeschen(
    loeschAnforderung: LoeschAnforderungResource,
    command: CreateCommand,
  ): void {
    this.store.dispatch(
      CommandActions.createCommand({
        resource: loeschAnforderung,
        linkRel: LoeschAnforderungLinkRel.EXECUTE_LOESCHEN,
        command,
      }),
    );
  }

  public getLoeschAnforderungZuruecknehmenCommand(): Observable<StateResource<CommandResource>> {
    return this.store.select(LoeschAnforderungSelectors.loeschAnforderungZuruecknehmenCommand);
  }

  public loeschAnforderungZuruecknehmen(
    loeschAnforderung: LoeschAnforderungResource,
    command: CreateCommand,
  ): void {
    this.store.dispatch(
      CommandActions.createCommand({
        resource: loeschAnforderung,
        linkRel: LoeschAnforderungLinkRel.ZURUECKNEHMEN,
        command,
      }),
    );
  }
}
