/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ConvertForDataTestPipe } from '@alfa-client/tech-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ReactiveFormsModule } from '@angular/forms';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatIcon } from '@angular/material/icon';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { MockComponent } from 'ng-mocks';
import { IconButtonWithSpinnerComponent } from '../../icon-button-with-spinner/icon-button-with-spinner.component';
import { CheckboxEnumEditorComponent } from './checkbox-enum-editor.component';

describe('CheckboxEnumEditorComponent', () => {
  let component: CheckboxEnumEditorComponent;
  let fixture: ComponentFixture<CheckboxEnumEditorComponent>;

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [ConvertForDataTestPipe],
      imports: [
        MatFormFieldModule,
        ReactiveFormsModule,
        BrowserAnimationsModule,
        CheckboxEnumEditorComponent,
        MatIcon,
        MockComponent(IconButtonWithSpinnerComponent),
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(CheckboxEnumEditorComponent);
    component = fixture.componentInstance;
    component.defaultItem = { type: 'enumType' };
    component.checkedItem = { type: 'positive' };
    component.uncheckedItem = { type: 'negative' };
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('setSelection', () => {
    const writeMethodMock = jest.fn();

    beforeEach(() => {
      component.writeValue = writeMethodMock;
    });

    it('should write checked value on selected', () => {
      component.setSelection({ source: null, checked: true });

      expect(writeMethodMock).toHaveBeenCalledWith('positive');
    });

    it('should write unchecked value on selected', () => {
      component.setSelection({ source: null, checked: false });

      expect(writeMethodMock).toHaveBeenCalledWith('negative');
    });
  });
});
