/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import {
  createEmptyStateResource,
  createErrorStateResource,
  createStateResource,
} from '@alfa-client/tech-shared';
import { UserProfileResource } from '@alfa-client/user-profile-shared';
import { getDataTestClassOf } from 'libs/tech-shared/test/data-test';
import { createApiError } from 'libs/tech-shared/test/error';
import { createUserProfileResource } from 'libs/user-profile-shared/test/user-profile';
import { UserProfileNameComponent } from './user-profile-name.component';

describe('UserProfileNameComponent', () => {
  let component: UserProfileNameComponent;
  let fixture: ComponentFixture<UserProfileNameComponent>;

  const userProfileName: string = getDataTestClassOf('user-profile-name');
  const userProfileNameUnknown: string = getDataTestClassOf('user-profile-name-unknown');

  const userProfile: UserProfileResource = createUserProfileResource();

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [UserProfileNameComponent],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(UserProfileNameComponent);
    component = fixture.componentInstance;
    component.userProfileStateResource = createEmptyStateResource();
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('if user-profile exists', () => {
    beforeEach(() => {
      component.userProfileStateResource = createStateResource(userProfile);
      fixture.detectChanges();
    });

    it('show user name', () => {
      const element = fixture.nativeElement.querySelector(userProfileName);

      expect(element).toBeInstanceOf(HTMLElement);
    });
  });

  describe('if user profile loading error', () => {
    beforeEach(() => {
      component.userProfileStateResource = createErrorStateResource(createApiError());
      fixture.detectChanges();
    });

    it('should show "Unbekannter Benutzer" as userName', () => {
      const element = fixture.nativeElement.querySelector(userProfileNameUnknown);

      expect(element).toBeInstanceOf(HTMLElement);
      expect((<HTMLElement>element).innerHTML).toContain('Unbekannter Benutzer');
    });
  });
});
