/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { Injectable, OnDestroy } from '@angular/core';
import { FormControl, FormGroup, UntypedFormBuilder } from '@angular/forms';
import { NavigationService } from '@alfa-client/navigation-shared';
import { isNotNil } from '@alfa-client/tech-shared';
import { VorgangListService } from '@alfa-client/vorgang-shared';
import { Subscription } from 'rxjs';

@Injectable()
export class VorgangFilterFormService implements OnDestroy {
  public form: FormGroup;

  static readonly FILTER: string = 'filter';

  public readonly FILTER_ALLE_VALUE: string = 'alle';
  public readonly FILTER_MEINE_VALUE: string = 'meine';
  public readonly FILTER_UNASSIGNED_VALUE: string = 'unassigned';

  private subscription: Subscription;

  constructor(
    private formBuilder: UntypedFormBuilder,
    private navigationService: NavigationService,
    private vorgangListService: VorgangListService,
  ) {
    this.init();
  }

  init(): void {
    this.initForm();

    this.subscribeToFilterChanges();
    this.subscribeToValueChanges();
  }

  private initForm(): void {
    this.form = this.formBuilder.group({
      [VorgangFilterFormService.FILTER]: new FormControl(),
    });
  }

  subscribeToFilterChanges(): void {
    this.subscription = this.vorgangListService
      .getSelectedFilterAsRouteParam()
      .subscribe((filter: string) => this.patch(filter));
  }

  private patch(filter: string): void {
    this.getFilterControl().patchValue(filter);
  }

  subscribeToValueChanges(): void {
    this.subscription = this.getFilterControl().valueChanges.subscribe((value) =>
      this.handleFilterChange(value),
    );
  }

  private getFilterControl(): FormControl {
    return <FormControl>this.form.controls[VorgangFilterFormService.FILTER];
  }

  private handleFilterChange(value: string): void {
    this.navigationService.navigateByFilter(value);
  }

  ngOnDestroy(): void {
    if (isNotNil(this.subscription)) this.subscription.unsubscribe();
  }
}
