/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { createStateResource, HasLinkPipe, StateResource } from '@alfa-client/tech-shared';
import { mock } from '@alfa-client/test-utils';
import { VorgangResource } from '@alfa-client/vorgang-shared';
import { WiedervorlageService } from '@alfa-client/wiedervorlage-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { createVorgangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent } from 'ng-mocks';
import { WiedervorlageListInVorgangContainerComponent } from './wiedervorlage-list-in-vorgang-container.component';
import { WiedervorlageListInVorgangComponent } from './wiedervorlage-list-in-vorgang/wiedervorlage-list-in-vorgang.component';

describe('WiedervorlageListInVorgangContainerComponent', () => {
  let component: WiedervorlageListInVorgangContainerComponent;
  let fixture: ComponentFixture<WiedervorlageListInVorgangContainerComponent>;

  const wiedervorlageService = mock(WiedervorlageService);

  const vorgangStateResource: StateResource<VorgangResource> = createStateResource(createVorgangResource());

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        WiedervorlageListInVorgangContainerComponent,
        HasLinkPipe,
        MockComponent(WiedervorlageListInVorgangComponent),
      ],
      providers: [
        {
          provide: WiedervorlageService,
          useValue: wiedervorlageService,
        },
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(WiedervorlageListInVorgangContainerComponent);
    component = fixture.componentInstance;
    component.vorgangStateResource = vorgangStateResource;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnChanges', () => {
    it('should call wiedervorlageService to get wiedervorlageList', () => {
      component.ngOnChanges();

      expect(wiedervorlageService.getWiedervorlageListByGivenVorgang).toHaveBeenCalledWith(vorgangStateResource.resource);
    });

    it('should call reloadWiedervorlageListOnVorgangReload', () => {
      const reloadWiedervorlageListOnVorgangReload = jest
        .spyOn(component, 'reloadWiedervorlageListOnVorgangReload')
        .mockReturnThis();

      component.ngOnChanges();

      expect(reloadWiedervorlageListOnVorgangReload).toHaveBeenCalled();
    });
  });

  describe('reloadWiedervorlageListOnVorgangReload', () => {
    beforeEach(() => {
      wiedervorlageService._setWiedervorlageListReload.mockClear();
    });

    it('should call wiedervorlageService', () => {
      component.vorgangStateResource = {
        ...createStateResource(createVorgangResource()),
        reload: true,
      };

      component.reloadWiedervorlageListOnVorgangReload();

      expect(wiedervorlageService._setWiedervorlageListReload).toHaveBeenCalled();
    });

    it('should not call wiedervorlageService', () => {
      component.vorgangStateResource = {
        ...createStateResource(createVorgangResource()),
        reload: false,
      };

      component.reloadWiedervorlageListOnVorgangReload();

      expect(wiedervorlageService._setWiedervorlageListReload).not.toHaveBeenCalled();
    });
  });
});
