/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ToEmbeddedResourcesPipe } from '@alfa-client/tech-shared';
import { createDialogRefMock, DialogRefMock, Mock, mock } from '@alfa-client/test-utils';
import { OrganisationsEinheitService, ZUSTAENDIGE_STELLE_SERVICE } from '@alfa-client/zustaendige-stelle-shared';
import { DIALOG_DATA, DialogRef } from '@angular/cdk/dialog';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { Resource } from '@ngxp/rest';
import { ButtonComponent, CloseIconComponent } from '@ods/system';
import { MockComponent } from 'ng-mocks';
import { SearchZustaendigeStelleDialogComponent } from '././search-zustaendige-stelle-dialog.component';
import { SearchZustaendigeStelleFormContainerComponent } from './search-zustaendige-stelle-form-container/search-zustaendige-stelle-form-container.component';

describe('SearchZustaendigeStelleDialogComponent', () => {
  let component: SearchZustaendigeStelleDialogComponent<Resource>;
  let fixture: ComponentFixture<SearchZustaendigeStelleDialogComponent<Resource>>;

  const service: Mock<OrganisationsEinheitService> = mock(OrganisationsEinheitService);
  const title: string = 'dummyTitle';

  let dialogRefMock: DialogRefMock;

  beforeEach(() => {
    dialogRefMock = createDialogRefMock();
  });

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        SearchZustaendigeStelleDialogComponent,
        ToEmbeddedResourcesPipe,
        MockComponent(SearchZustaendigeStelleFormContainerComponent),
        MockComponent(ButtonComponent),
        MockComponent(CloseIconComponent),
      ],
      providers: [
        {
          provide: ZUSTAENDIGE_STELLE_SERVICE,
          useValue: service,
        },
        {
          provide: DialogRef,
          useValue: dialogRefMock,
        },
        {
          provide: DIALOG_DATA,
          useValue: title,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(SearchZustaendigeStelleDialogComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('close dialog', () => {
    it('should clear search result', () => {
      component.closeDialog();

      expect(service.clearSearchResult).toHaveBeenCalled();
    });

    it('should close dialog', () => {
      component.closeDialog();

      expect(dialogRefMock.close).toHaveBeenCalled();
    });
  });
});
